@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0306';
+our $VERSION = '0.0307';
 
 use Moo;
 use strictures 2;
@@ -20,12 +20,6 @@ has names => (
 );
 
 
-has sizes => (
-    is      => 'ro',
-    default => sub { return { reverse %MIDI::Simple::Length } },
-);
-
-
 has size => (
     is      => 'ro',
     default => sub { return 4 },
@@ -125,7 +119,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0306
+version 0.0307
 
 =head1 SYNOPSIS
 
@@ -168,14 +162,6 @@ A hash reference of C<%MIDI::Simple::Length> (keyed by duration name).
 
 Default: C<%MIDI::Simple::Length>
 
-=head2 sizes
-
-  $sizes = $mdp->sizes;
-
-A hash reference of C<%MIDI::Simple::Length> (keyed by duration value).
-
-Default: C<reverse %MIDI::Simple::Length>
-
 =head2 size
 
   $size = $mdp->size;
